Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ARTESANATO PE DA SERRA LTDA
CNPJ: 03.691.278/0001-40 Inscrição Estadual: 1090260633
ESTRADA BR 158, 4295, KM 3, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 665 Série: 1 Data de Emissão: 11/06/2019 17:01:48
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0603 6912 7800 0140 6500 1000 0006 6514 2611 5970
Protocolo de Autorização: 143190788551043
CONSUMIDOR
Consumidor não identificado
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
4809 | REDE SIMPLES | 1 | UN | 110 | 110,00
Valor total R$ | 102,00
Valor descontos R$ | 8,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:25